@@ -9,9 +9,16 @@ library(ggplot2)
 ## ----Example Data head--------------------------------------------------------
 data(Example_data, package = "Covid19Wastewater")
 head(Example_data)%>%
+  select(date:PMMoV)%>%
   head()%>%
   knitr::kable()
 
+head(Example_data)%>%
+  select(flow:geo_mean)%>%
+  head()%>%
+  knitr::kable()
+
+
 ## ----plotting example data----------------------------------------------------
 ggplot(Example_data, aes(x=date, y=geo_mean, color = site)) +
   geom_point()
